terminate_markdown

Function terminate_markdown 

pub fn terminate_markdown(text: &str, opts: &TerminatorOptions) -> String
Terminate a streaming Markdown tail to avoid partial rendering artifacts.

This function is intentionally conservative and only modifies the pending tail.