pub fn terminate_markdown(text: &str, opts: &TerminatorOptions) -> StringExpand description
Terminate a streaming Markdown tail to avoid partial rendering artifacts.
This function is intentionally conservative and only modifies the pending tail.
pub fn terminate_markdown(text: &str, opts: &TerminatorOptions) -> StringTerminate a streaming Markdown tail to avoid partial rendering artifacts.
This function is intentionally conservative and only modifies the pending tail.